OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "未知地址",
    "No result." : "无结果。",
    "Malformed JSON data." : "JSON 数据格式错误。",
    "Error" : "错误",
    "Weather status" : "天气状况",
    "Weather status in your dashboard" : "仪表盘中的天气状况",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "仪表盘应用程序中集成的天气状况。\n用户可以自动或手动确定位置。然后会显示 6 小时的预报。\n此状况也可以集成到其他地方，例如日历应用。",
    "Detect location" : "检测地点",
    "Set custom address" : "自定义地址",
    "Favorites" : "收藏",
    "{temperature} {unit} clear sky later today" : "今天日晚些时候{temperature} {unit}晴天",
    "{temperature} {unit} clear sky" : "{temperature} {unit}晴天",
    "{temperature} {unit} cloudy later today" : "今日晚些时候{temperature} {unit}多云",
    "{temperature} {unit} cloudy" : "{temperature} {unit}多云",
    "{temperature} {unit} fair weather later today" : "今日晚些时候天气还行{temperature} {unit}",
    "{temperature} {unit} fair weather" : "{temperature} {unit}天气还行",
    "{temperature} {unit} partly cloudy later today" : "今日晚些时候{temperature} {unit}局部多云",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit}局部多云",
    "{temperature} {unit} foggy later today" : "今日晚些时候{temperature} {unit}有雾",
    "{temperature} {unit} foggy" : "{temperature} {unit}雾",
    "More weather for {adr}" : "{adr} 的更多天气信息",
    "Loading weather" : "正在加载天气",
    "Remove from favorites" : "从收藏夹移除",
    "Add as favorite" : "添加到收藏",
    "You are not logged in." : "您没有登录。",
    "There was an error getting the weather status information." : "获取天气状态信息时出错。",
    "No weather information found" : "找不到天气信息",
    "Location not found" : "找不到位置",
    "There was an error setting the location address." : "设置位置地址时出错。",
    "There was an error setting the location." : "设置位置时出错。",
    "There was an error saving the mode." : "保存模式时出错。",
    "There was an error using personal address." : "使用个人地址出错。",
    "Set location for weather" : "设置天气位置"
},
"nplurals=1; plural=0;");
